@@ -10,8 +10,8 @@
 #include "ac.h"
 #include "bbox.h"
 
-static void DoHStems(const ACFontInfo* fontinfo, PClrVal sLst1);
-static void DoVStems(PClrVal sLst);
+static void DoHStems(const ACFontInfo* fontinfo, HintVal* sLst1);
+static void DoVStems(HintVal* sLst);
 
 static bool CounterFailed;
 
@@ -19,14 +19,13 @@ void
 InitAll(const ACFontInfo* fontinfo, int32_t reason)
 {
     InitData(fontinfo, reason); /* must be first */
-    InitAuto(reason);
     InitFix(reason);
     InitGen(reason);
     InitPick(reason);
 }
 
 static int32_t
-PtLstLen(PClrPoint lst)
+PtLstLen(HintPoint* lst)
 {
     int32_t cnt = 0;
     while (lst != NULL) {
@@ -37,7 +36,7 @@ PtLstLen(PClrPoint lst)
 }
 
 static int32_t
-PointListCheck(PClrPoint new, PClrPoint lst)
+PointListCheck(HintPoint* new, HintPoint* lst)
 {
     /* -1 means not a member, 1 means already a member, 0 means conflicts */
     Fixed l1 = 0, l2 = 0, n1 = 0, n2 = 0, tmp, halfMargin;
@@ -69,8 +68,7 @@ PointListCheck(PClrPoint new, PClrPoint lst)
             break;
         }
         default: {
-            LogMsg(LOGERROR, NONFATALERROR,
-                   "Illegal character in point list in %s.\n", gGlyphName);
+            LogMsg(LOGERROR, NONFATALERROR, "Illegal character in point list.");
         }
     }
     if (n1 > n2) {
@@ -82,7 +80,7 @@ PointListCheck(PClrPoint new, PClrPoint lst)
         if (lst == NULL) {
             return -1;
         }
-        if (lst->c == ch) { /* same kind of color */
+        if (lst->c == ch) { /* same kind of hint */
             switch (ch) {
                 case 'y':
                 case 'm': {
@@ -107,7 +105,7 @@ PointListCheck(PClrPoint new, PClrPoint lst)
             }
             /* Add this extra margin to the band to fix a problem in
              TimesEuropa/Italic/v,w,y where a main hstem hint was
-             being merged with newcolors. This main hstem caused
+             being merged with newhints. This main hstem caused
              problems in rasterization so it shouldn't be included. */
             l1 -= halfMargin;
             l2 += halfMargin;
@@ -120,7 +118,7 @@ PointListCheck(PClrPoint new, PClrPoint lst)
 }
 
 static bool
-SameColorLists(PClrPoint lst1, PClrPoint lst2)
+SameHintLists(HintPoint* lst1, HintPoint* lst2)
 {
     if (PtLstLen(lst1) != PtLstLen(lst2)) {
         return false;
@@ -135,39 +133,39 @@ SameColorLists(PClrPoint lst1, PClrPoint lst2)
 }
 
 bool
-SameColors(int32_t cn1, int32_t cn2)
+SameHints(int32_t cn1, int32_t cn2)
 {
     if (cn1 == cn2) {
         return true;
     }
-    return SameColorLists(gPtLstArray[cn1], gPtLstArray[cn2]);
+    return SameHintLists(gPtLstArray[cn1], gPtLstArray[cn2]);
 }
 
 void
-MergeFromMainColors(char ch)
+MergeFromMainHints(char ch)
 {
-    PClrPoint lst;
+    HintPoint* lst;
     for (lst = gPtLstArray[0]; lst != NULL; lst = lst->next) {
         if (lst->c != ch) {
             continue;
         }
         if (PointListCheck(lst, gPointList) == -1) {
             if (ch == 'b') {
-                AddColorPoint(0, lst->y0, 0, lst->y1, ch, lst->p0, lst->p1);
+                AddHintPoint(0, lst->y0, 0, lst->y1, ch, lst->p0, lst->p1);
             } else {
-                AddColorPoint(lst->x0, 0, lst->x1, 0, ch, lst->p0, lst->p1);
+                AddHintPoint(lst->x0, 0, lst->x1, 0, ch, lst->p0, lst->p1);
             }
         }
     }
 }
 
 void
-AddColorPoint(Fixed x0, Fixed y0, Fixed x1, Fixed y1, char ch, PPathElt p0,
-              PPathElt p1)
+AddHintPoint(Fixed x0, Fixed y0, Fixed x1, Fixed y1, char ch, PathElt* p0,
+             PathElt* p1)
 {
-    PClrPoint pt;
+    HintPoint* pt;
     int32_t chk;
-    pt = (PClrPoint)Alloc(sizeof(ClrPoint));
+    pt = (HintPoint*)Alloc(sizeof(HintPoint));
     pt->x0 = x0;
     pt->y0 = y0;
     pt->x1 = x1;
@@ -178,28 +176,26 @@ AddColorPoint(Fixed x0, Fixed y0, Fixed x1, Fixed y1, char ch, PPathElt p0,
     pt->p0 = p0;
     pt->p1 = p1;
     chk = PointListCheck(pt, gPointList);
-    if (chk == 0 && gShowClrInfo) {
-        ReportColorConflict(x0, y0, x1, y1, ch);
+    if (chk == 0) {
+        ReportHintConflict(x0, y0, x1, y1, ch);
     }
     if (chk == -1) {
         pt->next = gPointList;
         gPointList = pt;
-        if (gLogging) {
-            LogColorInfo(gPointList);
-        }
+        LogHintInfo(gPointList);
     }
 }
 
 static void
-CopyClrFromLst(char clr, PClrPoint lst)
+CopyHintFromLst(char hint, HintPoint* lst)
 {
-    bool bvflg = (clr == 'b' || clr == 'v');
+    bool bvflg = (hint == 'b' || hint == 'v');
     while (lst != NULL) {
-        if (lst->c == clr) {
+        if (lst->c == hint) {
             if (bvflg) {
-                AddColorPoint(0, lst->y0, 0, lst->y1, clr, lst->p0, lst->p1);
+                AddHintPoint(0, lst->y0, 0, lst->y1, hint, lst->p0, lst->p1);
             } else {
-                AddColorPoint(lst->x0, 0, lst->x1, 0, clr, lst->p0, lst->p1);
+                AddHintPoint(lst->x0, 0, lst->x1, 0, hint, lst->p0, lst->p1);
             }
         }
         lst = lst->next;
@@ -209,26 +205,26 @@ CopyClrFromLst(char clr, PClrPoint lst)
 void
 CopyMainV(void)
 {
-    CopyClrFromLst('m', gPtLstArray[0]);
+    CopyHintFromLst('m', gPtLstArray[0]);
 }
 
 void
 CopyMainH(void)
 {
-    CopyClrFromLst('v', gPtLstArray[0]);
+    CopyHintFromLst('v', gPtLstArray[0]);
 }
 
 void
-AddHPair(PClrVal v, char ch)
+AddHPair(HintVal* v, char ch)
 {
-    Fixed bot, top, tmp;
-    PPathElt p0, p1, p;
-    bot = itfmy(v->vLoc1);
-    top = itfmy(v->vLoc2);
+    Fixed bot, top;
+    PathElt *p0, *p1, *p;
+    bot = -v->vLoc1;
+    top = -v->vLoc2;
     p0 = v->vBst->vSeg1->sElt;
     p1 = v->vBst->vSeg2->sElt;
     if (top < bot) {
-        tmp = top;
+        Fixed tmp = top;
         top = bot;
         bot = tmp;
         p = p0;
@@ -248,36 +244,36 @@ AddHPair(PClrVal v, char ch)
             bot = top + FixInt(21); /* width == -21 iff top seg is ghost */
         }
     }
-    AddColorPoint(0, bot, 0, top, ch, p0, p1);
+    AddHintPoint(0, bot, 0, top, ch, p0, p1);
 }
 
 void
-AddVPair(PClrVal v, char ch)
+AddVPair(HintVal* v, char ch)
 {
-    Fixed lft, rght, tmp;
-    PPathElt p0, p1, p;
-    lft = itfmx(v->vLoc1);
-    rght = itfmx(v->vLoc2);
+    Fixed lft, rght;
+    PathElt *p0, *p1, *p;
+    lft = v->vLoc1;
+    rght = v->vLoc2;
     p0 = v->vBst->vSeg1->sElt;
     p1 = v->vBst->vSeg2->sElt;
     if (lft > rght) {
-        tmp = lft;
+        Fixed tmp = lft;
         lft = rght;
         rght = tmp;
         p = p0;
         p0 = p1;
         p1 = p;
     }
-    AddColorPoint(lft, 0, rght, 0, ch, p0, p1);
+    AddHintPoint(lft, 0, rght, 0, ch, p0, p1);
 }
 
 static bool
-UseCounter(PClrVal sLst, bool mclr)
+UseCounter(HintVal* sLst, bool mhint)
 {
     int32_t cnt = 0;
     Fixed minLoc, midLoc, maxLoc, prevBstVal, bestVal;
-    Fixed minDelta, midDelta, maxDelta, loc, delta, th;
-    PClrVal lst, newLst;
+    Fixed minDelta, midDelta, maxDelta, th;
+    HintVal *lst, *newLst;
     minLoc = midLoc = maxLoc = FixInt(20000);
     minDelta = midDelta = maxDelta = 0;
     lst = sLst;
@@ -303,8 +299,8 @@ UseCounter(PClrVal sLst, bool mclr)
     }
     newLst = sLst;
     while (sLst != NULL) {
-        loc = sLst->vLoc1;
-        delta = sLst->vLoc2 - loc;
+        Fixed loc = sLst->vLoc1;
+        Fixed delta = sLst->vLoc2 - loc;
         loc += FixHalfMul(delta);
         if (loc < minLoc) {
             maxLoc = midLoc;
@@ -327,17 +323,18 @@ UseCounter(PClrVal sLst, bool mclr)
     th = FixInt(5) / 100;
     if (abs(minDelta - maxDelta) < th &&
         abs((maxLoc - midLoc) - (midLoc - minLoc)) < th) {
-        if (mclr) {
-            gVColoring = newLst;
+        if (mhint) {
+            gVHinting = newLst;
         } else {
-            gHColoring = newLst;
+            gHHinting = newLst;
         }
         return true;
     }
     if (abs(minDelta - maxDelta) < FixInt(3) &&
         abs((maxLoc - midLoc) - (midLoc - minLoc)) < FixInt(3)) {
-        ReportError(mclr ? "Near miss for using V counter hinting."
-                         : "Near miss for using H counter hinting.");
+        LogMsg(INFO, OK,
+               mhint ? "Near miss for using V counter hinting."
+                     : "Near miss for using H counter hinting.");
     }
     return false;
 }
@@ -346,10 +343,10 @@ static void
 GetNewPtLst(void)
 {
     if (gNumPtLsts >= gMaxPtLsts) { /* increase size */
-        PClrPoint* newArray;
+        HintPoint** newArray;
         int32_t i;
         gMaxPtLsts += 5;
-        newArray = (PClrPoint*)Alloc(gMaxPtLsts * sizeof(PClrPoint));
+        newArray = (HintPoint**)Alloc(gMaxPtLsts * sizeof(HintPoint*));
         for (i = 0; i < gMaxPtLsts - 5; i++) {
             newArray[i] = gPtLstArray[i];
         }
@@ -362,15 +359,15 @@ GetNewPtLst(void)
 }
 
 void
-XtraClrs(PPathElt e)
+XtraHints(PathElt* e)
 {
-    /* this can be simplified for standalone coloring */
+    /* this can be simplified for standalone hinting */
     gPtLstArray[gPtLstIndex] = gPointList;
-    if (e->newcolors == 0) {
+    if (e->newhints == 0) {
         GetNewPtLst();
-        e->newcolors = (int16_t)gPtLstIndex;
+        e->newhints = (int16_t)gPtLstIndex;
     }
-    gPtLstIndex = e->newcolors;
+    gPtLstIndex = e->newhints;
     gPointList = gPtLstArray[gPtLstIndex];
 }
 
@@ -378,7 +375,7 @@ static void
 Blues(const ACFontInfo* fontinfo)
 {
     Fixed pv = 0, pd = 0, pc = 0, pb = 0, pa = 0;
-    PClrVal sLst;
+    HintVal* sLst;
 
     /*
      Top alignment zones are in the global 'topBands', bottom in 'botBands'.
@@ -392,13 +389,13 @@ Blues(const ACFontInfo* fontinfo)
 
      HStems, Vstems are global lists of Fixed 24.8 numbers..
 
-     segLists is an array of 4  ClrSeg linked lists. list 0 and 1 are
+     segLists is an array of 4  HintSeg linked lists. list 0 and 1 are
     respectively up and down vertical segments. Lists 2 and 3 are
      respectively left pointing and right pointing horizontal segments. On a
     counter-clockwise path, this is the same as selecting
      top and bottom stem locations.
 
-     NoBlueChar() consults a hard-coded list of glyph names, If the glyph is in
+     NoBlueGlyph() consults a hard-coded list of glyph names, If the glyph is in
     this list, set the alignment zones (top and botBands) to empty.
 
      1) gen.c:GenHPts() . Buid the raw list of stem segments in global 'topList'
@@ -417,11 +414,9 @@ Blues(const ACFontInfo* fontinfo)
     segment end point,
      called H/VBends (segment type sBend=1). I have no idea what these are for.
 
-     AddSegment is pretty simple. It creates a new hint segment 'ClrSeg' for the
-    parent path elt , fills it in,
-     adds it to appropriate  list of the 4 segLists, and then sorts by hstem
-    location.
-     seg->sElt is the parent elt
+     AddSegment is pretty simple. It creates a new hint segment 'HintSeg' for
+    the parent path elt , fills it in, adds it to appropriate  list of the 4
+    segLists, and then sorts by hstem location. seg->sElt is the parent elt
      seg->sType is the type
      seg->sLoc is the location in Fixed 18.14: right shift 7 to get integer
     value.
@@ -493,7 +488,7 @@ Blues(const ACFontInfo* fontinfo)
                             scale weight by  of *(largest stem hint in HStems)/
     dy)**3.
 
-     AddHValue() decides whether add a (bottom, top)  pair of color segments.
+     AddHValue() decides whether add a (bottom, top)  pair of hint segments.
      Do not add the pair if:
      if weight (val) is 0,
      if both are sBEND segments
@@ -504,14 +499,14 @@ Blues(const ACFontInfo* fontinfo)
     skip
 
      else add it with eval.c:InsertHValue()
-     add new ClrVal to global valList.
+     add new HintVal to global valList.
      item->vVal = val; # weight
      item->initVal = val; # originl weight from EvalHPair()
      item->vSpc = spc; # priority
      item->vLoc1 = bot; # bottom Y value in Fixed 18.14
      item->vLoc2 = top; # top Y value in Fixed 18.14
-     item->vSeg1 = bSeg; # bottom color segment
-     item->vSeg2 = tSeg; # top color segment
+     item->vSeg1 = bSeg; # bottom hint segment
+     item->vSeg2 = tSeg; # top hint segment
      item->vGhst = ghst; # if it is a ghost segment.
      The new item is inserted after the first element where vlist->vLoc2 >= top
     and vlist->vLoc1 >= bottom
@@ -542,17 +537,13 @@ Blues(const ACFontInfo* fontinfo)
      4) pick.c:FindBestHVals();
      When a hint segment    */
 
-    if (gShowClrInfo) {
-        PrintMessage("generate blues");
-    }
-    if (NoBlueChar()) {
+    LogMsg(LOGDEBUG, OK, "generate blues");
+    if (NoBlueGlyph()) {
         gLenTopBands = gLenBotBands = 0;
     }
     GenHPts();
-    if (gShowClrInfo) {
-        PrintMessage("evaluate");
-    }
-    if (!CounterFailed && HColorChar()) {
+    LogMsg(LOGDEBUG, OK, "evaluate");
+    if (!CounterFailed && HHintGlyph()) {
         pv = gPruneValue;
         gPruneValue = (Fixed)gMinVal;
         pa = gPruneA;
@@ -569,48 +560,45 @@ Blues(const ACFontInfo* fontinfo)
     FindBestHVals();
     MergeVals(false);
 
-    if (gShowClrInfo) {
-        ShowHVals(gValList);
-        PrintMessage("pick best");
-    }
+    ShowHVals(gValList);
+    LogMsg(LOGDEBUG, OK, "pick best");
     MarkLinks(gValList, true);
     CheckVals(gValList, false);
     DoHStems(fontinfo, gValList); /* Report stems and alignment zones, if this
                                     has been requested. */
-    PickHVals(gValList); /* Moves best ClrVal items from valList to Hcoloring
-                           list. (? Choose from set of ClrVals for the samte
+    PickHVals(gValList); /* Moves best HintVal items from valList to Hhinting
+                           list. (? Choose from set of HintVals for the samte
                            stem values.) */
-    if (!CounterFailed && HColorChar()) {
+    if (!CounterFailed && HHintGlyph()) {
         gPruneValue = pv;
         gPruneD = pd;
         gPruneC = pc;
         gPruneB = pb;
         gPruneA = pa;
-        gUseH = UseCounter(gHColoring, false);
+        gUseH = UseCounter(gHHinting, false);
         if (!gUseH) { /* try to fix */
             AddBBoxHV(true, true);
-            gUseH = UseCounter(gHColoring, false);
+            gUseH = UseCounter(gHHinting, false);
             if (!gUseH) { /* still bad news */
-                ReportError("Note: Glyph is in list for using H counter hints, "
-                            "but didn't find any candidates.");
+                LogMsg(INFO, OK,
+                       "Glyph is in list for using H counter hints, "
+                       "but didn't find any candidates.");
                 CounterFailed = true;
             }
         }
     } else {
         gUseH = false;
     }
-    if (gHColoring == NULL) {
+    if (gHHinting == NULL) {
         AddBBoxHV(true, false);
     }
-    if (gShowClrInfo) {
-        PrintMessage("results");
-        PrintMessage(gUseH ? "rv" : "rb");
-        ShowHVals(gHColoring);
-    }
+    LogMsg(LOGDEBUG, OK, "results");
+    LogMsg(LOGDEBUG, OK, gUseH ? "rv" : "rb");
+    ShowHVals(gHHinting);
     if (gUseH) {
-        PrintMessage("Using H counter hints.");
+        LogMsg(INFO, OK, "Using H counter hints.");
     }
-    sLst = gHColoring;
+    sLst = gHHinting;
     while (sLst != NULL) {
         AddHPair(sLst, gUseH ? 'v' : 'b'); /* actually adds hint */
         sLst = sLst->vNxt;
@@ -618,27 +606,26 @@ Blues(const ACFontInfo* fontinfo)
 }
 
 static void
-DoHStems(const ACFontInfo* fontinfo, PClrVal sLst1)
+DoHStems(const ACFontInfo* fontinfo, HintVal* sLst1)
 {
-    Fixed bot, top;
-    Fixed charTop = INT32_MIN, charBot = INT32_MAX;
+    Fixed glyphTop = INT32_MIN, glyphBot = INT32_MAX;
     bool curved;
     if (!gDoAligns && !gDoStems) {
         return;
     }
     while (sLst1 != NULL) {
-        bot = itfmy(sLst1->vLoc1);
-        top = itfmy(sLst1->vLoc2);
+        Fixed bot = -sLst1->vLoc1;
+        Fixed top = -sLst1->vLoc2;
         if (top < bot) {
             Fixed tmp = top;
             top = bot;
             bot = tmp;
         }
-        if (top > charTop) {
-            charTop = top;
+        if (top > glyphTop) {
+            glyphTop = top;
         }
-        if (bot < charBot) {
-            charBot = bot;
+        if (bot < glyphBot) {
+            glyphBot = bot;
         }
         /* skip if ghost or not a line on top or bottom */
         if (sLst1->vGhst) {
@@ -650,13 +637,11 @@ DoHStems(const ACFontInfo* fontinfo, PClrVal sLst1)
         AddHStem(top, bot, curved);
         sLst1 = sLst1->vNxt;
         if (top != INT32_MIN || bot != INT32_MAX) {
-            AddStemExtremes(UnScaleAbs(fontinfo, bot),
-                            UnScaleAbs(fontinfo, top));
+            AddStemExtremes(bot, top);
         }
     }
-    if (charTop != INT32_MIN || charBot != INT32_MAX) {
-        AddCharExtremes(UnScaleAbs(fontinfo, charBot),
-                        UnScaleAbs(fontinfo, charTop));
+    if (glyphTop != INT32_MIN || glyphBot != INT32_MAX) {
+        AddGlyphExtremes(glyphBot, glyphTop);
     }
 }
 
@@ -664,15 +649,11 @@ static void
 Yellows(void)
 {
     Fixed pv = 0, pd = 0, pc = 0, pb = 0, pa = 0;
-    PClrVal sLst;
-    if (gShowClrInfo) {
-        PrintMessage("generate yellows");
-    }
-    GenVPts(SpecialCharType());
-    if (gShowClrInfo) {
-        PrintMessage("evaluate");
-    }
-    if (!CounterFailed && VColorChar()) {
+    HintVal* sLst;
+    LogMsg(LOGDEBUG, OK, "generate yellows");
+    GenVPts(SpecialGlyphType());
+    LogMsg(LOGDEBUG, OK, "evaluate");
+    if (!CounterFailed && VHintGlyph()) {
         pv = gPruneValue;
         gPruneValue = (Fixed)gMinVal;
         pa = gPruneA;
@@ -688,45 +669,42 @@ Yellows(void)
     PruneVVals();
     FindBestVVals();
     MergeVals(true);
-    if (gShowClrInfo) {
-        ShowVVals(gValList);
-        PrintMessage("pick best");
-    }
+    ShowVVals(gValList);
+    LogMsg(LOGDEBUG, OK, "pick best");
     MarkLinks(gValList, false);
     CheckVals(gValList, true);
     DoVStems(gValList);
     PickVVals(gValList);
-    if (!CounterFailed && VColorChar()) {
+    if (!CounterFailed && VHintGlyph()) {
         gPruneValue = pv;
         gPruneD = pd;
         gPruneC = pc;
         gPruneB = pb;
         gPruneA = pa;
-        gUseV = UseCounter(gVColoring, true);
+        gUseV = UseCounter(gVHinting, true);
         if (!gUseV) { /* try to fix */
             AddBBoxHV(false, true);
-            gUseV = UseCounter(gVColoring, true);
+            gUseV = UseCounter(gVHinting, true);
             if (!gUseV) { /* still bad news */
-                ReportError("Note: Glyph is in list for using V counter hints, "
-                            "but didn't find any candidates.");
+                LogMsg(INFO, OK,
+                       "Glyph is in list for using V counter hints, "
+                       "but didn't find any candidates.");
                 CounterFailed = true;
             }
         }
     } else {
         gUseV = false;
     }
-    if (gVColoring == NULL) {
+    if (gVHinting == NULL) {
         AddBBoxHV(false, false);
     }
-    if (gShowClrInfo) {
-        PrintMessage("results");
-        PrintMessage(gUseV ? "rm" : "ry");
-        ShowVVals(gVColoring);
-    }
+    LogMsg(LOGDEBUG, OK, "results");
+    LogMsg(LOGDEBUG, OK, gUseV ? "rm" : "ry");
+    ShowVVals(gVHinting);
     if (gUseV) {
-        PrintMessage("Using V counter hints.");
+        LogMsg(INFO, OK, "Using V counter hints.");
     }
-    sLst = gVColoring;
+    sLst = gVHinting;
     while (sLst != NULL) {
         AddVPair(sLst, gUseV ? 'm' : 'y');
         sLst = sLst->vNxt;
@@ -734,18 +712,18 @@ Yellows(void)
 }
 
 static void
-DoVStems(PClrVal sLst)
+DoVStems(HintVal* sLst)
 {
-    Fixed lft, rght;
-    bool curved;
     if (!gDoAligns && !gDoStems) {
         return;
     }
     while (sLst != NULL) {
+        Fixed lft, rght;
+        bool curved;
         curved = !FindLineSeg(sLst->vLoc1, leftList) &&
                  !FindLineSeg(sLst->vLoc2, rightList);
-        lft = itfmx(sLst->vLoc1);
-        rght = itfmx(sLst->vLoc2);
+        lft = sLst->vLoc1;
+        rght = sLst->vLoc2;
         if (lft > rght) {
             Fixed tmp = lft;
             lft = rght;
@@ -757,16 +735,16 @@ DoVStems(PClrVal sLst)
 }
 
 static void
-RemoveRedundantFirstColors(void)
+RemoveRedundantFirstHints(void)
 {
-    PPathElt e;
-    if (gNumPtLsts < 2 || !SameColors(0, 1)) {
+    PathElt* e;
+    if (gNumPtLsts < 2 || !SameHints(0, 1)) {
         return;
     }
     e = gPathStart;
     while (e != NULL) {
-        if (e->newcolors == 1) {
-            e->newcolors = 0;
+        if (e->newhints == 1) {
+            e->newhints = 0;
             return;
         }
         e = e->next;
@@ -774,7 +752,7 @@ RemoveRedundantFirstColors(void)
 }
 
 static void
-AddColorsSetup(void)
+AddHintsSetup(void)
 {
     int i;
     gVBigDist = 0;
@@ -783,7 +761,6 @@ AddColorsSetup(void)
             gVBigDist = gVStems[i];
         }
     }
-    gVBigDist = dtfmx(gVBigDist);
     if (gVBigDist < gInitBigDist) {
         gVBigDist = gInitBigDist;
     }
@@ -795,27 +772,26 @@ AddColorsSetup(void)
             gHBigDist = gHStems[i];
         }
     }
-    gHBigDist = abs(dtfmy(gHBigDist));
+    gHBigDist = abs(gHBigDist);
     if (gHBigDist < gInitBigDist) {
         gHBigDist = gInitBigDist;
     }
     gHBigDist = (gHBigDist * 23) / 20;
     acfixtopflt(gHBigDist, &gHBigDistR);
-    if ((!gScalingHints) && (gRoundToInt)) {
+    if (gRoundToInt) {
         RoundPathCoords();
     }
     CheckForMultiMoveTo();
     /* PreCheckForSolEol(); */
 }
 
-/* If extracolor is true then it is ok to have multi-level
- coloring. */
+/* If extrahint is true then it is ok to have multi-level
+ hinting. */
 static void
-AddColorsInnerLoop(const ACFontInfo* fontinfo, const char* srcglyph,
-                   bool extracolor)
+AddHintsInnerLoop(const ACFontInfo* fontinfo, const char* srcglyph,
+                  bool extrahint)
 {
-    int32_t solEolCode = 2, retryColoring = 0;
-    bool isSolEol = false;
+    int32_t retryHinting = 0;
     while (true) {
         PreGenPts();
         CheckSmooth();
@@ -824,39 +800,27 @@ AddColorsInnerLoop(const ACFontInfo* fontinfo, const char* srcglyph,
         if (!gDoAligns) {
             Yellows();
         }
-        if (gEditChar) {
+        if (gEditGlyph) {
             DoShuffleSubpaths();
         }
-        gHPrimary = CopyClrs(gHColoring);
-        gVPrimary = CopyClrs(gVColoring);
-        /*
-         isSolEol = SpecialSolEol() && !useV && !useH;
-         solEolCode = isSolEol? SolEolCharCode() : 2;
-         */
-        PruneElementColorSegs();
-        if (gListClrInfo) {
-            ListClrInfo();
-        }
-        if (extracolor) {
-            AutoExtraColors(MoveToNewClrs(), isSolEol, solEolCode);
+        gHPrimary = CopyHints(gHHinting);
+        gVPrimary = CopyHints(gVHinting);
+        PruneElementHintSegs();
+        ListHintInfo();
+        if (extrahint) {
+            AutoExtraHints(MoveToNewHints());
         }
         gPtLstArray[gPtLstIndex] = gPointList;
-        if (isSolEol) {
-            break;
-        }
-        retryColoring++;
-        /* we want to retry coloring if
+        retryHinting++;
+        /* we want to retry hinting if
          `1) CounterFailed or
          2) doFixes changed something, but in both cases, only on the first
          pass.
          */
-        if (CounterFailed && retryColoring == 1) {
+        if (CounterFailed && retryHinting == 1) {
             goto retry;
         }
-        if (!DoFixes()) {
-            break;
-        }
-        if (retryColoring > 1) {
+        if (retryHinting > 1) {
             break;
         }
     retry:
@@ -866,40 +830,35 @@ AddColorsInnerLoop(const ACFontInfo* fontinfo, const char* srcglyph,
             gReportRetryCB();
         }
         if (gPathStart == NULL || gPathStart == gPathEnd) {
-            LogMsg(LOGERROR, NONFATALERROR, "No glyph path in %s.\n",
-                   gGlyphName);
+            LogMsg(LOGERROR, NONFATALERROR, "No glyph path.");
         }
 
-        /* SaveFile(); SaveFile is always called in AddColorsCleanup, so this is
+        /* SaveFile(); SaveFile is always called in AddHintsCleanup, so this is
          * a duplciate */
         InitAll(fontinfo, RESTART);
-        if (gWriteColoredBez && !ReadGlyph(fontinfo, srcglyph, false, false)) {
+        if (gWriteHintedBez && !ReadGlyph(fontinfo, srcglyph, false, false)) {
             break;
         }
-        AddColorsSetup();
-        if (!PreCheckForColoring()) {
+        AddHintsSetup();
+        if (!PreCheckForHinting()) {
             break;
         }
         if (gFlexOK) {
             gHasFlex = false;
             AutoAddFlex();
         }
-        gReportErrors = false;
     }
 }
 
 static void
-AddColorsCleanup(const ACFontInfo* fontinfo)
+AddHintsCleanup(const ACFontInfo* fontinfo)
 {
-    RemoveRedundantFirstColors();
-    gReportErrors = true;
-    if (gWriteColoredBez) {
+    RemoveRedundantFirstHints();
+    if (gWriteHintedBez) {
 
         if (gPathStart == NULL || gPathStart == gPathEnd) {
             LogMsg(LOGERROR, NONFATALERROR,
-                   "The %s glyph path vanished while adding "
-                   "hints.\n",
-                   gGlyphName);
+                   "The glyph path vanished while adding hints.");
         } else {
             SaveFile(fontinfo);
         }
@@ -908,39 +867,36 @@ AddColorsCleanup(const ACFontInfo* fontinfo)
 }
 
 static void
-AddColors(const ACFontInfo* fontinfo, const char* srcglyph, bool extracolor)
+AddHints(const ACFontInfo* fontinfo, const char* srcglyph, bool extrahint)
 {
     if (gPathStart == NULL || gPathStart == gPathEnd) {
-        PrintMessage("No character path, so no hints.");
-        SaveFile(fontinfo); /* make sure it gets saved with no coloring */
+        LogMsg(INFO, OK, "No glyph path, so no hints.");
+        SaveFile(fontinfo); /* make sure it gets saved with no hinting */
         return;
     }
-    gReportErrors = true;
     CounterFailed = gBandError = false;
     CheckPathBBox();
     CheckForDups();
-    AddColorsSetup();
-    if (!PreCheckForColoring()) {
+    AddHintsSetup();
+    if (!PreCheckForHinting()) {
         return;
     }
     if (gFlexOK) {
         gHasFlex = false;
         AutoAddFlex();
     }
-    AddColorsInnerLoop(fontinfo, srcglyph, extracolor);
-    AddColorsCleanup(fontinfo);
+    AddHintsInnerLoop(fontinfo, srcglyph, extrahint);
+    AddHintsCleanup(fontinfo);
 }
 
 bool
-AutoColorGlyph(const ACFontInfo* fontinfo, const char* srcglyph,
-               bool extracolor)
+AutoHintGlyph(const ACFontInfo* fontinfo, const char* srcglyph, bool extrahint)
 {
     int32_t lentop = gLenTopBands, lenbot = gLenBotBands;
     if (!ReadGlyph(fontinfo, srcglyph, false, false)) {
-        LogMsg(LOGERROR, NONFATALERROR, "Cannot parse %s glyph.\n", gGlyphName);
+        LogMsg(LOGERROR, NONFATALERROR, "Cannot parse glyph.");
     }
-    PrintMessage(""); /* Just print the file name. */
-    AddColors(fontinfo, srcglyph, extracolor);
+    AddHints(fontinfo, srcglyph, extrahint);
     gLenTopBands = lentop;
     gLenBotBands = lenbot;
     return true;
